# -*- coding: utf-8 -*-

from django.conf import settings
from django.core.exceptions import ValidationError
import logging
import unittest


from ..models import BBCode
from ..parser import BBCodeParseError

logger = logging.getLogger("bbcode.bbcode")
logger.handlers = [logging.NullHandler()]


class TestBBCodeParser(unittest.TestCase):
    def test_create_from_user_input(self):
        bbcode = BBCode("message", "[b]Hello[/b], world! é", from_db=False)
        self.assertEqual(str(bbcode), "[b]Hello[/b], world! é")
        self.assertEqual(bbcode.as_text(), "Hello, world! é")
        self.assertEqual(bbcode.as_html(), "<b>Hello</b>, world! é")
        self.assertEqual(bbcode.serialize(), "\x01[b]Hello[/b], world! é")
        self.assertEqual(bbcode.summary(), "Hello, world! é")

        with self.assertRaises(ValidationError):
            BBCode("message", "[b]Hello, world! é", from_db=False)

    def test_create_from_db(self):
        bbcode = BBCode("message", "\x01[b]Hello[/b], world! é", from_db=True)
        self.assertEqual(str(bbcode), "[b]Hello[/b], world! é")
        self.assertEqual(bbcode.as_text(), "Hello, world! é")
        self.assertEqual(bbcode.as_html(), "<b>Hello</b>, world! é")

        orig_debug = settings.DEBUG

        try:
            settings.DEBUG = True

            with self.assertRaises(BBCodeParseError):
                BBCode("message", "abcdé", from_db=True)

            settings.DEBUG = False

        finally:
            settings.DEBUG = orig_debug

    def test_summary(self):
        bbcode = BBCode("message", "Line 1\n\nLine [b]3[/b]\nLine 4", from_db=False)
        self.assertEqual(bbcode.as_text(), "Line 1\n\nLine 3\nLine 4")
        self.assertEqual(bbcode.summary(), "Line 1\nLine 3\nLine 4")
        self.assertEqual(bbcode.summary(soft_limit=2, hard_limit=5), "Line …")
        self.assertEqual(bbcode.summary(soft_limit=2, hard_limit=20), "Line 1")
